==> huaweicloudsdkcdm-3.0.68-py2.py3-none-any.whl: huaweicloudsdkcdm/v1/model/create_and_start_random_cluster_job_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateAndStartRandomClusterJobResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'validation_result': 'list[JobValidationResult]'
    }

    attribute_map = {
        'name': 'name',
        'validation_result': 'validation-result'
    }

    def __init__(self, name=None, validation_result=None):
        """CreateAndStartRandomClusterJobResponse - a model defined in huaweicloud sdk"""
        
        super(CreateAndStartRandomClusterJobResponse, self).__init__()

        self._name = None
        self._validation_result = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if validation_result is not None:
            self.validation_result = validation_result

    @property
    def name(self):
        """Gets the name of this CreateAndStartRandomClusterJobResponse.

        作业名称。

        :return: The name of this CreateAndStartRandomClusterJobResponse.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateAndStartRandomClusterJobResponse.

        作业名称。

        :param name: The name of this CreateAndStartRandomClusterJobResponse.
        :type: str
        """
        self._name = name

    @property
    def validation_result(self):
        """Gets the validation_result of this CreateAndStartRandomClusterJobResponse.

        校验结果： - 如果修改失败，返回失败原因。 - 如果修改成功，返回空列表。

        :return: The validation_result of this CreateAndStartRandomClusterJobResponse.
        :rtype: list[JobValidationResult]
        """
        return self._validation_result

    @validation_result.setter
    def validation_result(self, validation_result):
        """Sets the validation_result of this CreateAndStartRandomClusterJobResponse.

        校验结果： - 如果修改失败，返回失败原因。 - 如果修改成功，返回空列表。

        :param validation_result: The validation_result of this CreateAndStartRandomClusterJobResponse.
        :type: list[JobValidationResult]
        """
        self._validation_result = validation_result

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateAndStartRandomClusterJobResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcdm-3.0.80-py2.py3-none-any.whl: huaweicloudsdkcdm/v1/model/create_and_start_random_cluster_job_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateAndStartRandomClusterJobResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'submissions': 'list[StartJobSubmission]'
    }

    attribute_map = {
        'submissions': 'submissions'
    }

    def __init__(self, submissions=None):
        """CreateAndStartRandomClusterJobResponse - a model defined in huaweicloud sdk"""
        
        super(CreateAndStartRandomClusterJobResponse, self).__init__()

        self._submissions = None
        self.discriminator = None

        if submissions is not None:
            self.submissions = submissions

    @property
    def submissions(self):
        """Gets the submissions of this CreateAndStartRandomClusterJobResponse.

        作业运行信息，请参见submission参数说明

        :return: The submissions of this CreateAndStartRandomClusterJobResponse.
        :rtype: list[StartJobSubmission]
        """
        return self._submissions

    @submissions.setter
    def submissions(self, submissions):
        """Sets the submissions of this CreateAndStartRandomClusterJobResponse.

        作业运行信息，请参见submission参数说明

        :param submissions: The submissions of this CreateAndStartRandomClusterJobResponse.
        :type: list[StartJobSubmission]
        """
        self._submissions = submissions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateAndStartRandomClusterJobResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
